@@ -1,3 +1,4 @@
+import os
 import sys
 
 # make sure gevent-socketio is not installed, as it conflicts with
@@ -23,7 +24,7 @@ from werkzeug.serving import run_with_reloader
 from .namespace import Namespace
 from .test_client import SocketIOTestClient
 
-__version__ = '3.1.2'
+__version__ = '3.2.1'
 
 
 class _SocketIOMiddleware(socketio.WSGIApp):
@@ -210,6 +211,12 @@ class SocketIO(object):
             self.server_options.pop('resource', None) or 'socket.io'
         if resource.startswith('/'):
             resource = resource[1:]
+        if os.environ.get('FLASK_RUN_FROM_CLI'):
+            if self.server_options.get('async_mode') is None:
+                app.logger.warning(
+                    'Flask-SocketIO is Running under Werkzeug, WebSocket is '
+                    'not available.')
+                self.server_options['async_mode'] = 'threading'
         self.server = socketio.Server(**self.server_options)
         self.async_mode = self.server.async_mode
         for handler in self.handlers:
